CREATE TABLE mantis_config_table (
config_id                NVARCHAR(64) NOT NULL,
project_id               INT DEFAULT 0 NOT NULL,
user_id                  INT DEFAULT 0 NOT NULL,
access_reqd              INT DEFAULT 0,
type                     INT DEFAULT 90,
value                    TEXT NOT NULL,
                 PRIMARY KEY (config_id, project_id, user_id)
);

CREATE INDEX idx_config ON mantis_config_table (config_id);

CREATE TABLE mantis_bug_file_table (
id                       INT IDENTITY(1,1) NOT NULL,
bug_id                   INT DEFAULT 0 NOT NULL,
title                    NVARCHAR(250) DEFAULT '' NOT NULL,
description              NVARCHAR(250) DEFAULT '' NOT NULL,
diskfile                 NVARCHAR(250) DEFAULT '' NOT NULL,
filename                 NVARCHAR(250) DEFAULT '' NOT NULL,
folder                   NVARCHAR(250) DEFAULT '' NOT NULL,
filesize                 INT DEFAULT 0 NOT NULL,
file_type                NVARCHAR(250) DEFAULT '' NOT NULL,
date_added               DATETIME,
content                  IMAGE NULL,
                 PRIMARY KEY (id)
);

CREATE INDEX idx_bug_file_bug_id ON mantis_bug_file_table (bug_id);

CREATE TABLE mantis_bug_history_table (
id                       INT IDENTITY(1,1) NOT NULL,
user_id                  INT DEFAULT 0 NOT NULL,
bug_id                   INT DEFAULT 0 NOT NULL,
date_modified            DATETIME,
field_name               NVARCHAR(32) DEFAULT '' NOT NULL,
old_value                NVARCHAR(128) DEFAULT '' NOT NULL,
new_value                NVARCHAR(128) DEFAULT '' NOT NULL,
type                     SMALLINT DEFAULT 0 NOT NULL,
                 PRIMARY KEY (id)
);

CREATE INDEX idx_bug_history_bug_id ON mantis_bug_history_table (bug_id);

CREATE INDEX idx_history_user_id ON mantis_bug_history_table (user_id);

CREATE TABLE mantis_bug_monitor_table (
user_id                  INT DEFAULT 0 NOT NULL,
bug_id                   INT DEFAULT 0 NOT NULL,
                 PRIMARY KEY (user_id, bug_id)
);

CREATE TABLE mantis_bug_relationship_table (
id                       INT IDENTITY(1,1) NOT NULL,
source_bug_id            INT DEFAULT 0 NOT NULL,
destination_bug_id       INT DEFAULT 0 NOT NULL,
relationship_type        SMALLINT DEFAULT 0 NOT NULL,
                 PRIMARY KEY (id)
);

CREATE INDEX idx_relationship_source ON mantis_bug_relationship_table (source_bug_id);

CREATE INDEX idx_relationship_destination ON mantis_bug_relationship_table (destination_bug_id);

CREATE TABLE mantis_bug_table (
id                       INT IDENTITY(1,1) NOT NULL,
project_id               INT DEFAULT 0 NOT NULL,
reporter_id              INT DEFAULT 0 NOT NULL,
handler_id               INT DEFAULT 0 NOT NULL,
duplicate_id             INT DEFAULT 0 NOT NULL,
priority                 SMALLINT DEFAULT 30 NOT NULL,
severity                 SMALLINT DEFAULT 50 NOT NULL,
reproducibility          SMALLINT DEFAULT 10 NOT NULL,
status                   SMALLINT DEFAULT 10 NOT NULL,
resolution               SMALLINT DEFAULT 10 NOT NULL,
projection               SMALLINT DEFAULT 10 NOT NULL,
category                 NVARCHAR(64),
date_submitted           DATETIME,
last_updated             DATETIME,
eta                      SMALLINT DEFAULT 10 NOT NULL,
bug_text_id              INT DEFAULT 0 NOT NULL,
os                       NVARCHAR(32) DEFAULT '' NOT NULL,
os_build                 NVARCHAR(32) DEFAULT '' NOT NULL,
platform                 NVARCHAR(32) DEFAULT '' NOT NULL,
version                  NVARCHAR(64) DEFAULT '' NOT NULL,
fixed_in_version         NVARCHAR(64) DEFAULT '' NOT NULL,
build                    NVARCHAR(32) DEFAULT '' NOT NULL,
profile_id               INT DEFAULT 0 NOT NULL,
view_state               SMALLINT DEFAULT 10 NOT NULL,
summary                  NVARCHAR(128) DEFAULT '' NOT NULL,
sponsorship_total        INT DEFAULT 0 NOT NULL,
sticky                   BIT DEFAULT '0' NOT NULL,
                 PRIMARY KEY (id)
);

CREATE INDEX idx_bug_sponsorship_total ON mantis_bug_table (sponsorship_total);

CREATE INDEX idx_bug_fixed_in_version ON mantis_bug_table (fixed_in_version);

CREATE INDEX idx_bug_status ON mantis_bug_table (status);

CREATE INDEX idx_project ON mantis_bug_table (project_id);

CREATE TABLE mantis_bug_text_table (
id                       INT IDENTITY(1,1) NOT NULL,
description              TEXT NOT NULL,
steps_to_reproduce       TEXT NOT NULL,
additional_information   TEXT NOT NULL,
                 PRIMARY KEY (id)
);

CREATE TABLE mantis_bugnote_table (
id                       INT IDENTITY(1,1) NOT NULL,
bug_id                   INT DEFAULT 0 NOT NULL,
reporter_id              INT DEFAULT 0 NOT NULL,
bugnote_text_id          INT DEFAULT 0 NOT NULL,
view_state               SMALLINT DEFAULT 10 NOT NULL,
date_submitted           DATETIME,
--last_modified            DATETIME,
note_type                INT DEFAULT 0,
note_attr                NVARCHAR(250) DEFAULT '',
                 PRIMARY KEY (id)
);

CREATE INDEX idx_bug ON mantis_bugnote_table (bug_id);

--CREATE INDEX idx_last_mod ON mantis_bugnote_table (last_modified);

CREATE TABLE mantis_bugnote_text_table (
id                       INT IDENTITY(1,1) NOT NULL,
note                     TEXT NOT NULL,
                 PRIMARY KEY (id)
);

CREATE TABLE mantis_custom_field_project_table (
field_id                 INT DEFAULT 0 NOT NULL,
project_id               INT DEFAULT 0 NOT NULL,
sequence                 SMALLINT DEFAULT 0 NOT NULL,
                 PRIMARY KEY (field_id, project_id)
);

CREATE TABLE mantis_custom_field_string_table (
field_id                 INT DEFAULT 0 NOT NULL,
bug_id                   INT DEFAULT 0 NOT NULL,
value                    NVARCHAR(255) DEFAULT '' NOT NULL,
                 PRIMARY KEY (field_id, bug_id)
);

CREATE INDEX idx_custom_field_bug ON mantis_custom_field_string_table (bug_id);

CREATE TABLE mantis_custom_field_table (
id                       INT IDENTITY(1,1) NOT NULL,
name                     NVARCHAR(64) DEFAULT '' NOT NULL,
type                     SMALLINT DEFAULT 0 NOT NULL,
possible_values          TEXT NOT NULL,
default_value            NVARCHAR(255) DEFAULT '' NOT NULL,
valid_regexp             NVARCHAR(255) DEFAULT '' NOT NULL,
access_level_r           SMALLINT DEFAULT 0 NOT NULL,
access_level_rw          SMALLINT DEFAULT 0 NOT NULL,
length_min               INT DEFAULT 0 NOT NULL,
length_max               INT DEFAULT 0 NOT NULL,
advanced                 BIT,
require_report           BIT DEFAULT '0' NOT NULL,
require_update           BIT DEFAULT '0' NOT NULL,
display_report           BIT DEFAULT '0' NOT NULL,
display_update           BIT DEFAULT '1' NOT NULL,
require_resolved         BIT DEFAULT '0' NOT NULL,
display_resolved         BIT DEFAULT '0' NOT NULL,
display_closed           BIT DEFAULT '0' NOT NULL,
require_closed           BIT DEFAULT '0' NOT NULL,
                 PRIMARY KEY (id)
);

CREATE INDEX idx_custom_field_name ON mantis_custom_field_table (name);

CREATE TABLE mantis_filters_table (
id                       INT IDENTITY(1,1) NOT NULL,
user_id                  INT DEFAULT 0 NOT NULL,
project_id               INT DEFAULT 0 NOT NULL,
is_public                BIT DEFAULT NULL,
name                     NVARCHAR(64) DEFAULT '' NOT NULL,
filter_string            TEXT NOT NULL,
                 PRIMARY KEY (id)
);

CREATE TABLE mantis_news_table (
id                       INT IDENTITY(1,1) NOT NULL,
project_id               INT DEFAULT 0 NOT NULL,
poster_id                INT DEFAULT 0 NOT NULL,
date_posted              DATETIME,
last_modified            DATETIME,
view_state               SMALLINT DEFAULT 10 NOT NULL,
announcement             BIT DEFAULT '0' NOT NULL,
headline                 NVARCHAR(64) DEFAULT '' NOT NULL,
body                     TEXT NOT NULL,
                 PRIMARY KEY (id)
);

CREATE TABLE mantis_project_category_table (
project_id               INT DEFAULT 0 NOT NULL,
category                 NVARCHAR(64) DEFAULT '' NOT NULL,
user_id                  INT DEFAULT 0 NOT NULL,
                 PRIMARY KEY (project_id, category)
);

CREATE TABLE mantis_project_file_table (
id                       INT IDENTITY(1,1) NOT NULL,
project_id               INT DEFAULT 0 NOT NULL,
title                    NVARCHAR(250) DEFAULT '' NOT NULL,
description              NVARCHAR(250) DEFAULT '' NOT NULL,
diskfile                 NVARCHAR(250) DEFAULT '' NOT NULL,
filename                 NVARCHAR(250) DEFAULT '' NOT NULL,
folder                   NVARCHAR(250) DEFAULT '' NOT NULL,
filesize                 INT DEFAULT 0 NOT NULL,
file_type                NVARCHAR(250) DEFAULT '' NOT NULL,
date_added               DATETIME,
content                  IMAGE NOT NULL,
                 PRIMARY KEY (id)
);

CREATE TABLE mantis_project_hierarchy_table (
child_id                 INT NOT NULL,
parent_id                INT NOT NULL
);

CREATE TABLE mantis_project_table (
id                       INT IDENTITY(1,1) NOT NULL,
name                     NVARCHAR(128) DEFAULT '' NOT NULL,
status                   SMALLINT DEFAULT 10 NOT NULL,
enabled                  BIT DEFAULT '1' NOT NULL,
view_state               SMALLINT DEFAULT 10 NOT NULL,
access_min               SMALLINT DEFAULT 10 NOT NULL,
file_path                NVARCHAR(250) DEFAULT '' NOT NULL,
description              TEXT NOT NULL,
                 PRIMARY KEY (id)
);

CREATE INDEX idx_project_id ON mantis_project_table (id);

CREATE UNIQUE INDEX idx_project_name ON mantis_project_table (name);

CREATE INDEX idx_project_view ON mantis_project_table (view_state);

CREATE TABLE mantis_project_user_list_table (
project_id               INT DEFAULT 0 NOT NULL,
user_id                  INT DEFAULT 0 NOT NULL,
access_level             SMALLINT DEFAULT 10 NOT NULL,
                 PRIMARY KEY (project_id, user_id)
);

CREATE INDEX idx_project_user ON mantis_project_user_list_table (user_id);

CREATE TABLE mantis_project_version_table (
id                       INT IDENTITY(1,1) NOT NULL,
project_id               INT DEFAULT 0 NOT NULL,
version                  NVARCHAR(64) DEFAULT '' NOT NULL,
date_order               DATETIME,
description              TEXT NOT NULL,
released                 BIT DEFAULT '1' NOT NULL,
                 PRIMARY KEY (id)
);

CREATE UNIQUE INDEX idx_project_version ON mantis_project_version_table (project_id, version);

CREATE TABLE mantis_sponsorship_table (
id                       INT IDENTITY(1,1) NOT NULL,
bug_id                   INT DEFAULT 0 NOT NULL,
user_id                  INT DEFAULT 0 NOT NULL,
amount                   INT DEFAULT 0 NOT NULL,
logo                     NVARCHAR(128) DEFAULT '' NOT NULL,
url                      NVARCHAR(128) DEFAULT '' NOT NULL,
paid                     BIT DEFAULT '0' NOT NULL,
date_submitted           DATETIME,
last_updated             DATETIME,
                 PRIMARY KEY (id)
);

CREATE INDEX idx_sponsorship_bug_id ON mantis_sponsorship_table (bug_id);

CREATE INDEX idx_sponsorship_user_id ON mantis_sponsorship_table (user_id);

CREATE TABLE mantis_tokens_table (
id                       INT IDENTITY(1,1) NOT NULL,
owner                    INT NOT NULL,
type                     INT NOT NULL,
timestamp                DATETIME NOT NULL,
expiry                   DATETIME NULL,
value                    TEXT NOT NULL,
                 PRIMARY KEY (id)
);

CREATE TABLE mantis_user_pref_table (
id                       INT IDENTITY(1,1) NOT NULL,
user_id                  INT DEFAULT 0 NOT NULL,
project_id               INT DEFAULT 0 NOT NULL,
default_profile          INT DEFAULT 0 NOT NULL,
default_project          INT DEFAULT 0 NOT NULL,
advanced_report          BIT,
advanced_view            BIT,
advanced_update          BIT,
refresh_delay            INT DEFAULT 0 NOT NULL,
redirect_delay           INT NOT NULL,
bugnote_order            NVARCHAR(4) DEFAULT 'ASC' NOT NULL,
email_on_new             BIT DEFAULT '0' NOT NULL,
email_on_assigned        BIT DEFAULT '0' NOT NULL,
email_on_feedback        BIT DEFAULT '0' NOT NULL,
email_on_resolved        BIT DEFAULT '0' NOT NULL,
email_on_closed          BIT DEFAULT '0' NOT NULL,
email_on_reopened        BIT DEFAULT '0' NOT NULL,
email_on_bugnote         BIT DEFAULT '0' NOT NULL,
email_on_status          BIT DEFAULT '0' NOT NULL,
email_on_priority        BIT DEFAULT '0' NOT NULL,
email_on_priority_min_severity SMALLINT DEFAULT 10 NOT NULL,
email_on_status_min_severity SMALLINT DEFAULT 10 NOT NULL,
email_on_bugnote_min_severity SMALLINT DEFAULT 10 NOT NULL,
email_on_reopened_min_severity SMALLINT DEFAULT 10 NOT NULL,
email_on_closed_min_severity SMALLINT DEFAULT 10 NOT NULL,
email_on_resolved_min_severity SMALLINT DEFAULT 10 NOT NULL,
email_on_feedback_min_severity SMALLINT DEFAULT 10 NOT NULL,
email_on_assigned_min_severity SMALLINT DEFAULT 10 NOT NULL,
email_on_new_min_severity SMALLINT DEFAULT 10 NOT NULL,
email_bugnote_limit      SMALLINT DEFAULT 0 NOT NULL,
language                 NVARCHAR(32) DEFAULT 'english' NOT NULL,
                 PRIMARY KEY (id)
);

CREATE TABLE mantis_user_print_pref_table (
user_id                  INT DEFAULT 0 NOT NULL,
print_pref               NVARCHAR(27) DEFAULT '' NOT NULL,
                 PRIMARY KEY (user_id)
);

CREATE TABLE mantis_user_profile_table (
id                       INT IDENTITY(1,1) NOT NULL,
user_id                  INT DEFAULT 0 NOT NULL,
platform                 NVARCHAR(32) DEFAULT '' NOT NULL,
os                       NVARCHAR(32) DEFAULT '' NOT NULL,
os_build                 NVARCHAR(32) DEFAULT '' NOT NULL,
description              TEXT NOT NULL,
                 PRIMARY KEY (id)
);

CREATE TABLE mantis_user_table (
id                       INT IDENTITY(1,1) NOT NULL,
username                 NVARCHAR(32) DEFAULT '' NOT NULL,
realname                 NVARCHAR(64) DEFAULT '' NOT NULL,
email                    NVARCHAR(64) DEFAULT '' NOT NULL,
password                 NVARCHAR(32) DEFAULT '' NOT NULL,
date_created             DATETIME,
last_visit               DATETIME,
enabled                  BIT DEFAULT '1' NOT NULL,
protected                BIT DEFAULT '0' NOT NULL,
access_level             SMALLINT DEFAULT 10 NOT NULL,
login_count              INT DEFAULT 0 NOT NULL,
lost_password_request_count SMALLINT DEFAULT 0 NOT NULL,
failed_login_count       SMALLINT DEFAULT 0 NOT NULL,
cookie_string            NVARCHAR(64) DEFAULT '' NOT NULL,
                 PRIMARY KEY (id)
);

CREATE UNIQUE INDEX idx_user_cookie_string ON mantis_user_table (cookie_string);

CREATE UNIQUE INDEX idx_user_username ON mantis_user_table (username);

CREATE INDEX idx_enable ON mantis_user_table (enabled);

CREATE INDEX idx_access ON mantis_user_table (access_level);

INSERT INTO mantis_user_table(username, realname, email, password, date_created, last_visit, enabled, protected, access_level, login_count, lost_password_request_count, failed_login_count, cookie_string) VALUES
        ('administrator', '', 'root@localhost', '63a9f0ea7bb98050796b649e85481845', '2015-01-07 14:24:51', '2015-01-07 14:24:51', '1', '0', 90, 3, 0, 0, '89963aaec5833f997ca6201fc37854202579c98988ebebe11147f6e9739198ca');

ALTER TABLE mantis_bug_history_table ALTER COLUMN old_value NVARCHAR(255)  NOT NULL;

ALTER TABLE mantis_bug_history_table ALTER COLUMN new_value NVARCHAR(255)  NOT NULL;

CREATE TABLE mantis_email_table (
email_id                 INT IDENTITY(1,1) NOT NULL,
email                    NVARCHAR(64) DEFAULT '' NOT NULL,
subject                  NVARCHAR(250) DEFAULT '' NOT NULL,
submitted                DATETIME,
metadata                 TEXT NOT NULL,
body                     TEXT NOT NULL,
                 PRIMARY KEY (email_id)
);

CREATE INDEX idx_email_id ON mantis_email_table (email_id);

ALTER TABLE mantis_bug_table  ADD
 target_version NVARCHAR(64) DEFAULT '' NOT NULL;

ALTER TABLE mantis_bugnote_table  ADD
 time_tracking INT DEFAULT 0 NOT NULL;

CREATE INDEX idx_diskfile ON mantis_bug_file_table (diskfile);

ALTER TABLE mantis_user_print_pref_table ALTER COLUMN print_pref NVARCHAR(64)  NOT NULL;

ALTER TABLE mantis_bug_history_table ALTER COLUMN field_name NVARCHAR(64)  NOT NULL;

CREATE TABLE mantis_tag_table (
id                       INT IDENTITY(1,1) NOT NULL,
user_id                  INT DEFAULT 0 NOT NULL,
name                     NVARCHAR(100) DEFAULT '' NOT NULL,
description              TEXT NOT NULL,
date_created             DATETIME,
date_updated             DATETIME,
                 PRIMARY KEY (id, name)
);

CREATE TABLE mantis_bug_tag_table (
bug_id                   INT DEFAULT 0 NOT NULL,
tag_id                   INT DEFAULT 0 NOT NULL,
user_id                  INT DEFAULT 0 NOT NULL,
date_attached            DATETIME,
                 PRIMARY KEY (bug_id, tag_id)
);

CREATE INDEX idx_typeowner ON mantis_tokens_table (type, owner);

CREATE TABLE mantis_plugin_table (
basename                 NVARCHAR(40) NOT NULL,
enabled                  BIT DEFAULT '0' NOT NULL,
                 PRIMARY KEY (basename)
);

ALTER TABLE mantis_user_pref_table ALTER COLUMN redirect_delay INT;

ALTER TABLE mantis_user_pref_table ADD CONSTRAINT DF__mantis_user_pref_table__redirect_delay__302c DEFAULT 0 FOR redirect_delay;

ALTER TABLE mantis_user_pref_table ALTER COLUMN redirect_delay INT NOT NULL;

ALTER TABLE mantis_custom_field_table ALTER COLUMN possible_values TEXT;

ALTER TABLE mantis_custom_field_table ADD CONSTRAINT DF__mantis_custom_field_table__possible_values__1cb4 DEFAULT '' FOR possible_values;

ALTER TABLE mantis_custom_field_table ALTER COLUMN possible_values TEXT NOT NULL;

CREATE TABLE mantis_category_table (
id                       INT IDENTITY(1,1) NOT NULL,
project_id               INT DEFAULT 0 NOT NULL,
user_id                  INT DEFAULT 0 NOT NULL,
name                     NVARCHAR(128) DEFAULT '' NOT NULL,
status                   INT DEFAULT 0 NOT NULL,
                 PRIMARY KEY (id)
);

CREATE UNIQUE INDEX idx_category_project_name ON mantis_category_table (project_id, name);

INSERT INTO mantis_category_table
        ( project_id, user_id, name, status ) VALUES
        ( '0', '0', 'General', '0' ) ;

ALTER TABLE mantis_bug_table  ADD
 category_id INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_bug_table
 DROP COLUMN category;

DROP TABLE mantis_project_category_table;

ALTER TABLE mantis_project_table  ADD
 category_id INT DEFAULT 1 NOT NULL;

INSERT INTO mantis_plugin_table
        ( basename, enabled ) VALUES
        ( 'MantisCoreFormatting', '1' );

ALTER TABLE mantis_project_table  ADD
 inherit_global INT DEFAULT 0 NOT NULL;

ALTER TABLE mantis_project_hierarchy_table  ADD
 inherit_parent INT DEFAULT 0 NOT NULL;

ALTER TABLE mantis_plugin_table  ADD
 protected BIT DEFAULT '0' NOT NULL, 
 priority INT DEFAULT 3 NOT NULL;

ALTER TABLE mantis_project_version_table  ADD
 obsolete BIT DEFAULT '0' NOT NULL;

ALTER TABLE mantis_bug_table  ADD
 due_date DATETIME;

ALTER TABLE mantis_custom_field_table  ADD
 filter_by BIT DEFAULT '1' NOT NULL;

CREATE TABLE mantis_bug_revision_table (
id                       INT IDENTITY(1,1) NOT NULL,
bug_id                   INT NOT NULL,
bugnote_id               INT DEFAULT 0 NOT NULL,
user_id                  INT NOT NULL,
timestamp                INT DEFAULT 1 NOT NULL,
type                     INT NOT NULL,
value                    TEXT NOT NULL,
                 PRIMARY KEY (id)
);

CREATE INDEX idx_bug_rev_id_time ON mantis_bug_revision_table (bug_id, timestamp);

CREATE INDEX idx_bug_rev_type ON mantis_bug_revision_table (type);

ALTER TABLE mantis_bug_table  ADD
 date_submitted_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_bug_table  ADD
 due_date_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_bug_table  ADD
 last_updated_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_bug_table
 DROP COLUMN date_submitted;

EXEC sp_rename 'mantis_bug_table.date_submitted_int','date_submitted';

ALTER TABLE mantis_bug_table
 DROP COLUMN due_date;

EXEC sp_rename 'mantis_bug_table.due_date_int','due_date';

ALTER TABLE mantis_bug_table
 DROP COLUMN last_updated;

EXEC sp_rename 'mantis_bug_table.last_updated_int','last_updated';

ALTER TABLE mantis_bugnote_table  ADD
 last_modified_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_bugnote_table  ADD
 date_submitted_int INT DEFAULT 1 NOT NULL;

--ALTER TABLE mantis_bugnote_table
-- DROP COLUMN last_modified;

EXEC sp_rename 'mantis_bugnote_table.last_modified_int','last_modified';

CREATE INDEX idx_last_mod ON mantis_bugnote_table (last_modified);

ALTER TABLE mantis_bugnote_table
 DROP COLUMN date_submitted;

EXEC sp_rename 'mantis_bugnote_table.date_submitted_int','date_submitted';

ALTER TABLE mantis_bug_file_table  ADD
 date_added_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_bug_file_table
 DROP COLUMN date_added;

EXEC sp_rename 'mantis_bug_file_table.date_added_int','date_added';

ALTER TABLE mantis_project_file_table  ADD
 date_added_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_project_file_table
 DROP COLUMN date_added;

EXEC sp_rename 'mantis_project_file_table.date_added_int','date_added';

ALTER TABLE mantis_bug_history_table  ADD
 date_modified_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_bug_history_table
 DROP COLUMN date_modified;

EXEC sp_rename 'mantis_bug_history_table.date_modified_int','date_modified';

ALTER TABLE mantis_user_table  ADD
 last_visit_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_user_table  ADD
 date_created_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_user_table
 DROP COLUMN date_created;

EXEC sp_rename 'mantis_user_table.date_created_int','date_created';

ALTER TABLE mantis_user_table
 DROP COLUMN last_visit;

EXEC sp_rename 'mantis_user_table.last_visit_int','last_visit';

ALTER TABLE mantis_email_table  ADD
 submitted_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_email_table
 DROP COLUMN submitted;

EXEC sp_rename 'mantis_email_table.submitted_int','submitted';

ALTER TABLE mantis_tag_table  ADD
 date_created_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_tag_table  ADD
 date_updated_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_tag_table
 DROP COLUMN date_created;

EXEC sp_rename 'mantis_tag_table.date_created_int','date_created';

ALTER TABLE mantis_tag_table
 DROP COLUMN date_updated;

EXEC sp_rename 'mantis_tag_table.date_updated_int','date_updated';

ALTER TABLE mantis_bug_tag_table  ADD
 date_attached_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_bug_tag_table
 DROP COLUMN date_attached;

EXEC sp_rename 'mantis_bug_tag_table.date_attached_int','date_attached';

ALTER TABLE mantis_tokens_table  ADD
 timestamp_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_tokens_table  ADD
 expiry_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_tokens_table
 DROP COLUMN timestamp;

EXEC sp_rename 'mantis_tokens_table.timestamp_int','timestamp';

ALTER TABLE mantis_tokens_table
 DROP COLUMN expiry;

EXEC sp_rename 'mantis_tokens_table.expiry_int','expiry';

ALTER TABLE mantis_news_table  ADD
 last_modified_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_news_table  ADD
 date_posted_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_news_table
 DROP COLUMN last_modified;

EXEC sp_rename 'mantis_news_table.last_modified_int','last_modified';

ALTER TABLE mantis_news_table
 DROP COLUMN date_posted;

EXEC sp_rename 'mantis_news_table.date_posted_int','date_posted';

ALTER TABLE mantis_user_pref_table  ADD
 timezone NVARCHAR(32) DEFAULT '' NOT NULL;

ALTER TABLE mantis_project_version_table  ADD
 date_order_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_project_version_table
 DROP COLUMN date_order;

EXEC sp_rename 'mantis_project_version_table.date_order_int','date_order';

ALTER TABLE mantis_sponsorship_table  ADD
 date_submitted_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_sponsorship_table  ADD
 last_updated_int INT DEFAULT 1 NOT NULL;

ALTER TABLE mantis_sponsorship_table
 DROP COLUMN last_updated;

EXEC sp_rename 'mantis_sponsorship_table.last_updated_int','last_updated';

ALTER TABLE mantis_sponsorship_table
 DROP COLUMN date_submitted;

EXEC sp_rename 'mantis_sponsorship_table.date_submitted_int','date_submitted';

ALTER TABLE mantis_project_file_table  ADD
 user_id INT DEFAULT 0 NOT NULL;

ALTER TABLE mantis_bug_file_table  ADD
 user_id INT DEFAULT 0 NOT NULL;

ALTER TABLE mantis_custom_field_table
 DROP COLUMN advanced;

ALTER TABLE mantis_user_pref_table
 DROP COLUMN advanced_report;

ALTER TABLE mantis_user_pref_table
 DROP COLUMN advanced_view;

ALTER TABLE mantis_user_pref_table
 DROP COLUMN advanced_update;

CREATE INDEX idx_project_hierarchy_child_id ON mantis_project_hierarchy_table (child_id);

CREATE INDEX idx_project_hierarchy_parent_id ON mantis_project_hierarchy_table (parent_id);

CREATE INDEX idx_tag_name ON mantis_tag_table (name);

CREATE INDEX idx_bug_tag_tag_id ON mantis_bug_tag_table (tag_id);

INSERT INTO mantis_config_table ( value, type, access_reqd, config_id, project_id, user_id ) VALUES ('183', 1, 90, 'database_version', 0, 0 );

